From: Linus Torvalds Date: Sun, 12 Feb 2006 05:06:38 GMT Subject: Re: [PATCH] binary-tree-based objects. Message-ID: In-Reply-To: <7vhd75fc6y.fsf_-_@assigned-by-dhcp.cox.net> On Sat, 11 Feb 2006, Junio C Hamano wrote: > > * I haven't benched this seriously yet. One datapoint: > > time git-rev-list --objects v2.6.15..linus | wc -l > > are 53sec vs 22sec improvement with the same output. Another datapoint: doing time git-rev-list --objects HEAD > /dev/null three times in a row (to verify that the numbers are stable - they very clearly are). Before: real 0m41.322s user 0m40.612s sys 0m0.492s real 0m40.797s user 0m40.140s sys 0m0.468s real 0m40.433s user 0m40.016s sys 0m0.412s After: real 0m22.542s user 0m22.080s sys 0m0.448s real 0m22.660s user 0m22.336s sys 0m0.312s real 0m22.671s user 0m22.236s sys 0m0.292s and doing some trivial oprofile runs shows that the object lookup is no longer dominant (my libc's don't have symbol information, so I don't get good profile data, but it shows that libc and libz are the biggest issues, with memcmp and malloc/free apparently being much bigger issues than the object lookup). Linus